@@ -4,12 +4,14 @@ use clap::{Arg, Command};
 mod decrypt;
 mod encrypt;
 mod erase;
+mod file;
+mod hashing;
 mod prompt;
 mod structs;
 
 fn main() -> Result<()> {
     let matches = Command::new("dexios")
-        .version("5.0.15")
+        .version("6.0.1")
         .author("brxken128 <github.com/brxken128>")
         .about("Secure command-line encryption of files.")
         .subcommand_required(true)
